using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using System.Data;
using Syncfusion.Windows.Forms.Grid;

namespace Forum
{
	public class FrozenRow
	{
		public FrozenRow()
		{
		}

		//the FrozenRow grid
		private GridControl FrozenRowGrid = null;

		//the main grid
		private GridControlBase grid;
	
		#region wiring the main grid

		public void WireFrozenRow(GridControlBase grid)
		{
			if(FrozenRowGrid != null)
				throw new ArgumentException("grid already wired");

			this.grid = grid;

			this.FrozenRowGrid = new GridControl();
			this.FrozenRowGrid.ColCount = grid.Model.ColCount;
			this.FrozenRowGrid.RowCount = 1;
			this.FrozenRowGrid.Rows.Hidden[0] = true;
			this.FrozenRowGrid.VScrollBehavior = GridScrollbarMode.Disabled;
			this.FrozenRowGrid.HScrollBehavior = GridScrollbarMode.Disabled;
			this.FrozenRowGrid.ThemesEnabled = this.grid.ThemesEnabled;
			this.FrozenRowGrid.TabStop = false;

			this.FrozenRowGrid.DefaultRowHeight = this.grid.DefaultRowHeight;
			this.FrozenRowGrid.TableStyle = this.grid.Model.TableStyle;
			

			this.FrozenRowGrid.Model.QueryColWidth += new GridRowColSizeEventHandler(FrozenGrid_QueryColWidth);
			this.FrozenRowGrid.PrepareViewStyleInfo += new GridPrepareViewStyleInfoEventHandler(FrozenGrid_PrepareViewStyleInfo);

			this.grid.Model.ColWidthsChanged += new GridRowColSizeChangedEventHandler(grid_ColWidthsChanged);
			this.grid.Layout += new LayoutEventHandler(grid_Layout);
			this.grid.LeftColChanged += new GridRowColIndexChangedEventHandler(grid_LeftColChanged);
			this.grid.Model.ColsMoved += new GridRangeMovedEventHandler(grid_ColsMoved);

			this.grid.Controls.Add(this.FrozenRowGrid);

			SiteFrozenRow();
			this.grid.Refresh();
			
		}
		#endregion

		public void SiteFrozenRow()
		{
			this.grid.ResetGridBounds();

			this.grid.GridBounds = new Rectangle(this.grid.GridBounds.X,
				this.grid.GridBounds.Y,
				this.grid.GridBounds.Width,
				this.grid.GridBounds.Height - this.grid.DefaultRowHeight);
			int height = this.grid.GridBounds.Height + this.grid.DefaultRowHeight;

			this.FrozenRowGrid.Location = new Point(0, height - this.grid.DefaultRowHeight);

			this.FrozenRowGrid.Size = new Size(this.grid.ClientSize.Width, this.grid.DefaultRowHeight);
		}


		#region  Event Handlers on the main grid

		private void grid_ColsMoved(object sender, GridRangeMovedEventArgs e)
		{
			this.FrozenRowGrid.Cols.MoveRange(e.From, e.Count, e.Target);
		}

		private void grid_ColWidthsChanged(object sender, GridRowColSizeChangedEventArgs e)
		{
			this.FrozenRowGrid.Refresh();
		}

		private void grid_Layout(object sender, LayoutEventArgs e)
		{
			SiteFrozenRow();
		}

		private void grid_LeftColChanged(object sender, GridRowColIndexChangedEventArgs e)
		{
			this.FrozenRowGrid.LeftColIndex = this.grid.LeftColIndex;
		}
		#endregion

		#region Event handlers on the Summary Grid

		private void FrozenGrid_PrepareViewStyleInfo(object sender, GridPrepareViewStyleInfoEventArgs e)
		{
	
			if(e.ColIndex > 0 && e.RowIndex > 0)
			{
				e.Style.Borders.Top = new GridBorder(GridBorderStyle.Dotted);
			}
			if(e.ColIndex == 0 && e.RowIndex > 0)
			{
				e.Style.CellValue = this.grid.Model.RowCount+1;
				e.Style.Interior = this.grid.Model[1, 0].Interior;
			}
		}

		private void FrozenGrid_QueryColWidth(object sender, GridRowColSizeEventArgs e)
		{
			e.Size = this.grid.Model.ColWidths[e.Index];
			e.Handled = true;
		}

		# endregion

	}
}